**EN 1992-2 - November 2005
Eurocode 2: Design of concrete structures
Part 2: Concrete bridges - Design and detailing rules**

The table presents a list of formulas from the Eurocode 2 standards for concrete structures, tracking their implementation status 
( :x: or :heavy_check_mark: ) and any pertinent remarks. The 'Object Name' column references the corresponding Python entities inside of Blueprints.

Total of 7 tables present.

| Table number |        Done        | Remarks | Object name                                         |
|:-------------|:------------------:|:--------|:----------------------------------------------------|
| 7.101N       |        :x:         |         |                                                     |
| 8.101N       |        :x:         |         |                                                     |
| B.101        |        :x:         |         |                                                     |
| KK.101       |        :x:         |         |                                                     |
| NN.1         |        :x:         |         |                                                     |
| NN.2         |        :x:         |         |                                                     |
| NN.3         |        :x:         |         |                                                     |
